<?php

/***************************************************************************
 *                            lang_admin.php [Swedish]
 *                              -------------------
 *     begin                : Sat Dec 16 2000
 *     copyright            : (C) 2001 The phpBB Group
 *     email                : support@phpbb.com
 *
 *     $Id: lang_admin.php,v 1.1.2.1 2002/05/19 17:32:51 psotfx Exp $
 *
 ****************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

//  *************************************
//  First, original Swedish translation by:
//	
//	Marcus Svensson
//      admin@world-of-war.com
//      http://www.world-of-war.com
//	-------------------------------------
// 	Janke Rnnblom
//	jan-ake.ronnblom@skeria.skelleftea.se
//	-------------------------------------
//	Bruce
//	bruce@webway.se
//	-------------------------------------
//      Jakob Persson
//      jakob.persson@iname.com
//      http://www.jakob-persson.com
//
//  *************************************
//  Maintained and kept up-to-date by:
//  
//  Jonathan Gulbrandsen (Virtuality)
//  virtuality@carlssonplanet.com
//  http://www.carlssonplanet.com
//  *************************************
//

// CONTRIBUTORS:
//	 Add your details here if wanted, e.g. Name, username, email address, website
// XXXX-XX-XX  Orginal translation to Swedish by Marcus Svensson, Janke Rnnblom, Bruce and Jakob Persson
// 2003-07-31  Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)        - updated to 2.0.5
// 2003-08-12  Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)        - updated to 2.0.6
// 2005-01-31  Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)        - updated to 2.0.11

//
// Format is same as lang_main
//

//
// Modules, this replaces the keys used
// in the modules[][] arrays in each module file
//
$lang['General'] = "Generell admin";
$lang['Users'] = "Anvndaradmin";
$lang['Groups'] = "Gruppadmin";
$lang['Forums'] = "Forumadmin";
$lang['Styles'] = "Stiladmin";

$lang['Configuration'] = "Konfiguration";
$lang['Permissions'] = "Rttigheter";
$lang['Manage'] = "Hantering";
$lang['Disallow'] = "Frbjuda namn";
$lang['Prune'] = "Reducering";
$lang['Mass_Email'] = "Mass email";
$lang['Ranks'] = "Ranker";
$lang['Smilies'] = "Smilies";
$lang['Ban_Management'] = "Bannlys";
$lang['Word_Censor'] = "Ordcensur";
$lang['Export'] = "Exportera";
$lang['Create_new'] = "Skapa";
$lang['Add_new'] = "Lgg till";
$lang['Backup_DB'] = "Backup av databas";
$lang['Restore_DB'] = "terstll databas";


//
// Index
//
$lang['Admin'] = "Administration";
$lang['Not_admin'] = "Du har inte rttighet att administrera detta forum";
$lang['Welcome_phpBB'] = "Vlkommen till phpBB";
$lang['Admin_intro'] = "Tack fr att du har valt phpBB som din forumlsning. Den hr sidan ger dig en snabb verblick ver all mjlig statistik om ditt forum. Du kan komma tillbaka till den hr sidan genom att klicka p <u>Admin index</u> lnken p den vnstra sidan. Fr att komma tillbaka till indexet till forumet tryck p phpBB logon, som finns i den vnstra panelen. De vriga lnkarna p vnster hand lter dig kontrollera alla aspekter p hur ditt forum presenteras, varje sidan har intruktioner p hur du anvnder verktygen.";
$lang['Main_index'] = "Forumindex";
$lang['Forum_stats'] = "Forumstatistik";
$lang['Admin_Index'] = "Admin index";
$lang['Preview_forum'] = "Frhandsgranska forum";

$lang['Click_return_admin_index'] = "Klicka %sHr%s fr att tervnda till Admin index";

$lang['Statistic'] = "Statistik";
$lang['Value'] = "Vrde";
$lang['Number_posts'] = "Antal inlgg";
$lang['Posts_per_day'] = "Inlgg per dag";
$lang['Number_topics'] = "Antal mnen";
$lang['Topics_per_day'] = "mnen per dag";
$lang['Number_users'] = "Antal anvndare";
$lang['Users_per_day'] = "Anvndare per dag";
$lang['Board_started'] = "Start av forum";
$lang['Avatar_dir_size'] = "Avatarkatalogens storlek";
$lang['Database_size'] = "Databasstorlek";
$lang['Gzip_compression'] ="Gzip komprimering";
$lang['Not_available'] = "Inte tillgnglig";

$lang['ON'] = "P"; // This is for GZip compression
$lang['OFF'] = "AV"; 


//
// DB Utils
//
$lang['Database_Utilities'] = "Databasverktyg";

$lang['Restore'] = "terstll";
$lang['Backup'] = "Backup";
$lang['Restore_explain'] = "Detta kommer att utfra en fullstndig terstllning av alla phpBB tabeller frn en sparad fil. Om din server stdjer det kan du ladda upp en gzip komprimerad text fil vilken kommer att dekomprimeras. <b>VARNING</b>Detta kommer att skriva ver all existerande data. terstllningen kan ta en lng tid att utfra men lmna inte denna sida frrn den r frdig.";
$lang['Backup_explain'] = "Hr kan du ta backup p alla dina phpBB relaterade data. Om du har andra egna tabeller i samma databas som phpBB som du ocks vill skerhetskopiera s ange deras namn separerad med komman i \"vriga tabeller\"-rutan nedanfr Om din server stjder det kan du ocks gzip komprimera filen fr att minska storleken innan du laddar ner den.";

$lang['Backup_options'] = "Backup alternativ";
$lang['Start_backup'] = "Starta backup";
$lang['Full_backup'] = "Fullstndig backup";
$lang['Structure_backup'] = "Enbart backup av strukturen";
$lang['Data_backup'] = "Backup av endast data";
$lang['Additional_tables'] = "vriga tabeller";
$lang['Gzip_compress'] = "Gzip komprimera filen";
$lang['Select_file'] = "Vlj en fil";
$lang['Start_Restore'] = "Starta terstllningen";

$lang['Restore_success'] = "Databasen r terstlld utan problem.<br /><br />Ditt forum br vara tillbaka i samma skick som nr du gjorde backupen.";
$lang['Backup_download'] = "Din nedladdning kommer att starta snart, var god vnta tills den startar";
$lang['Backups_not_supported'] = "Tyvrr s stds inte backup n av ditt databassystem";

$lang['Restore_Error_uploading'] = "Fel nr filen skulle laddas upp.";
$lang['Restore_Error_filename'] = "Problem med filnamnet, frsk med en annan fil";
$lang['Restore_Error_decompress'] = "Kunde inte dekomprimera gzip fil, frsk ladda upp en textversion";
$lang['Restore_Error_no_file'] = "Ingen fil r uppladdad";


//
// Auth pages
//
$lang['Select_a_User'] = "Vlj en anvndare";
$lang['Select_a_Group'] = "Vlj en grupp";
$lang['Select_a_Forum'] = "Vlj ett forum";
$lang['Auth_Control_User'] = "Anvndarrttigheter"; 
$lang['Auth_Control_Group'] = "Grupprttigheter"; 
$lang['Auth_Control_Forum'] = "Forumrttigheter"; 
$lang['Look_up_User'] = "Sl upp en anvndare"; 
$lang['Look_up_Group'] = "Sl upp en grupp"; 
$lang['Look_up_Forum'] = "Sl upp ett forum"; 

$lang['Group_auth_explain'] = "Hr kan du ndra rttigheter och moderatorstatus fr varje grupp. Glm inte att fastn du ndrar grupprttigheten att anvndarens egna rttigheter fortfarande kan ge dom access till forum, m.m. Du kommer att f en varning i s fall.";
$lang['User_auth_explain'] = "Hr kan du ndra rttigheter och moderator status fr varje enskild anvndare. Glm inte att fastn du ndrar grupp rttigheten att anvndarens egna rttigheter fortfarande kan ge dom access till forum, m.m. Du kommer att f en varning i s fall.";
$lang['Forum_auth_explain'] = "Hr kan du ndra auktorisionsniver fr varje forum. Du har bde en enkel och en avancerad metod fr att gra detta, avancerad ger dig strre kontroll ver varje forums funktioner. Kom ihg att nr du ndrar rttigheterna till forumet s pverkar du vilka anvndare som kan utfra olika funktioner i forumet.";

$lang['Simple_mode'] = "Enkelt lge";
$lang['Advanced_mode'] = "Avancerat lge";
$lang['Moderator_status'] = "Moderator status";

$lang['Allowed_Access'] = "Tillt tilltrde";
$lang['Disallowed_Access'] = "Neka tilltrde";
$lang['Is_Moderator'] = "r Moderator";
$lang['Not_Moderator'] = "r inte moderator";

$lang['Conflict_warning'] = "Varning! Auktorisationskonflikt";
$lang['Conflict_access_userauth'] = "Denna anvndare har fortfarande tillgng till detta forum via gruppmedlemskap. Du kanske vill ndra grupprttigheterna eller ta bort denna anvndare frn gruppen fr att frhindra att de har tilltrde. Gruppens rttigheter (och berrda forum) listas nedan.";
$lang['Conflict_mod_userauth'] = "Anvndaren har fortfarande moderatorrttigheter till forumet via gruppmedlemskap. Du kan antingen ndra grupprttigheterna eller ta bort denna anvndare frn gruppen fr att frhindra att de har moderatorrttigheter. Gruppens rttigheter (och berrda forum) listas nedan.";

$lang['Conflict_access_groupauth'] = "Fljande anvndare har fortfarande tkomstrttigheter till detta forum via deras anvndarrttigheter. Du kanske vill ndra anvndarrttigheterna fr att frhindra dem frn att ha tkomst till forumet. Anvndarens rttigheter (och berrda forum) listas nedan.";
$lang['Conflict_mod_groupauth'] = "Fljande anvndare har fortfarande moderatorrttigheter till forumet via anvndarrttigheter. Du kanske vill ndra anvndarrttigheterna fr att frhindra dem frn att ha tkomst till forumet. Anvndarens rttigheter (och berrda forum) listas nedan.";

$lang['Public'] = "Publik";
$lang['Private'] = "Privat";
$lang['Registered'] = "Registrerad";
$lang['Administrators'] = "Administratrer";
$lang['Hidden'] = "Dold";

// These are displayed in the drop down boxes for advanced
// mode forum auth, try and keep them short!
$lang['Forum_ALL'] = "ALLA";
$lang['Forum_REG'] = "REG";
$lang['Forum_PRIVATE'] = "PRIVAT";
$lang['Forum_MOD'] = "MOD";
$lang['Forum_ADMIN'] = "ADMIN";

$lang['View'] = "Visa";
$lang['Read'] = "Ls";
$lang['Post'] = "Inlgg";
$lang['Reply'] = "Svara";
$lang['Edit'] = "ndra";
$lang['Delete'] = "Radera";
$lang['Sticky'] = "Klibbig";
$lang['Announce'] = "Viktigt meddelande"; 
$lang['Vote'] = "Rsta";
$lang['Pollcreate'] = "Skapa omrstning";

$lang['Permissions'] = "Rttigheter";
$lang['Simple_Permission'] = "Enkla rttigheter";

$lang['User_Level'] = "Anvndarniv"; 
$lang['Auth_User'] = "Anvndare";
$lang['Auth_Admin'] = "Administratr";
$lang['Group_memberships'] = "Gruppmedlemskap";
$lang['Usergroup_members'] = "Den hr gruppen har fljande medlemmar";

$lang['Forum_auth_updated'] = "Forumrttigeheterna r uppdaterade";
$lang['User_auth_updated'] = "Anvndarrttigeheterna r uppdaterade";
$lang['Group_auth_updated'] = "Grupprttigeheterna r uppdaterade";

$lang['Auth_updated'] = "Rttigheterna r uppdaterade";
$lang['Click_return_userauth'] = "Klicka %shr%s fr att terg till anvndarrttigheter";
$lang['Click_return_groupauth'] = "Klicka %shr%s fr att terg till grupprttigheter";
$lang['Click_return_forumauth'] = "Klicka %shr%s  fr att terg till forumrttigheter";


//
// Banning
//
$lang['Ban_control'] = "Bannlysningskontroll";
$lang['Ban_explain'] = "Hr skter du bannlysningen av anvndare. Du kan uppn detta genom att bannlysa vilket som helst eller alla av en anvndare eller en srskild eller ett omrde av IP adresser eller vrdnamn. Dessa metoder frhindrar en anvndare frn att n index sidan p ditt forum. Fr att frhindra en anvndare att registrera under ett annat anvndarnamn kan du ocks ange en bannlyst epostadress. Notera att bannlysa enbart en epostadress inte kommer att frhindra anvndaren frn att logga p eller skriva ett inlgg p ditt forum, du br anvnda ngon av de tv frsta metoderna fr att uppn det.";
$lang['Ban_explain_warn'] = "Notera att genom att ange ett omrde av IP adresser s resulterar det i att alla adresser mellan start och slut lggs till i banlysningslistan. En anstrngning kommer att gras fr att minska antalet adresser som lggs in i databasen genom att introducera jokertecken automatiskt dr det r lmpligt. Om du verkligen mste ange ett omrde av adresser s frsk hlla det litet eller nnu bttre frska att explicit ange enstaka adresserna.";

$lang['Select_username'] = "Vlj ett anvndarnamn";
$lang['Select_ip'] = "Vlj en IP adress";
$lang['Select_email'] = "Vlj en e-post adress";

$lang['Ban_username'] = "Bannlys en eller flera anvndare";
$lang['Ban_username_explain'] = 'Du kan banna flera anvndare p en gng genom att anvnda den rtta kombinationen mellan mus och tangentbord';

$lang['Ban_IP'] = "Bannlys en eller flera IP adresser eller vrdnamn";
$lang['IP_hostname'] = "IP adresser eller vrdnamn";
$lang['Ban_IP_explain'] = "Fr att specifiera flera olika IP adresser eller vrdnamn, skilj dem t med kommatecken. Fr att specifiera en rad olika IP adresser separera brjan och slutet med ett bindesstreck(-), fr att specifiera ett wildcard (vad som helst) anvnd *";

$lang['Ban_email'] = "Bannlys en eller flera epost adresser";
$lang['Ban_email_explain'] = "Fr att specificera mer n en e-post adress, skilj dem t med kommatecken. Fr att specifiera ett wildcard (vad som helst) namn anvnd *, till exempel *@hotmail.com";

$lang['Unban_username'] = "Hv en eller flera bannlysta anvndare";
$lang['Unban_username_explain'] = "Du kan ta bort flera bannlysningar samtidigt genom att anvnda den ndamlsenliga kombinationen av mus och tangenbord fr din dator och weblsare.";

$lang['Unban_IP'] = "Hv en eller flera bannlysta IP adresser";
$lang['Unban_IP_explain'] = "Du kan ta bort flera bannlysningar av IP adresser samtidigt genom att anvnda den ndamlsenliga kombinationen av mus och tangenbord fr din dator och weblsare.";

$lang['Unban_email'] = "Hv en eller flera bannlysta e-post adresser";
$lang['Unban_email_explain'] = "Du kan ta bort flera bannlysningar av e-post adresser samtidigt genom att anvnda den ndamlsenliga kombinationen av mus och tangenbord fr din dator och weblsare.";

$lang['No_banned_users'] = "Inga bannlysta anvndarnamn";
$lang['No_banned_ip'] = "Inga bannlysta IP adresser";
$lang['No_banned_email'] = "Inga bannlysta e-post adresser";

$lang['Ban_update_sucessful'] = "Banlistan har blivit uppdaterad.";
$lang['Click_return_banadmin'] = "Klicka %shr%s fr att tervnda till bannlysningskontrollen";


//
// Configuration
//
$lang['General_Config'] = "Generell Konfiguration";
$lang['Config_explain'] = "Formulret hr ger dig mjlighet att ndra alla allmnna foruminstllningar. Fr anvndar och forumkonfiguration s nvnd de relaterade lnkarna p vnster sida.";

$lang['Click_return_config'] = "Klicka %shr%s fr att tervnda till Generell Konfiguration";

$lang['General_settings'] = "Generella foruminstllningar";
$lang['Server_name'] = "Domnnamn";
$lang['Server_name_explain'] = "Domnnamnet som forumet krs frn";
$lang['Script_path'] = "Skriptskvg";
$lang['Script_path_explain'] = "Skvgen dr phpBB2 r placerat under domnnamnet (domnnamn.com/skvg)";
$lang['Server_port'] = "Serverport";
$lang['Server_port_explain'] = "Porten som servern krs p, vanligtvis 80, ndra bara om porten r annorlunda";
$lang['Site_name'] = "Sitenamn";
$lang['Site_desc'] = "Sitebeskrivning";
$lang['Board_disable'] = "Stng av forumet";
$lang['Board_disable_explain'] = "Detta gr forumet otillgngligt fr anvndarna. Logga inte ut nr du har deaktiverat forumet, du kommer inte att kunna logga in igen!";
$lang['Acct_activation'] = "Aktivera kontoaktivering";
$lang['Acc_None'] = "Ingen"; // These three entries are the type of activation
$lang['Acc_User'] = "Anvndare";
$lang['Acc_Admin'] = "Administratr";

$lang['Abilities_settings'] = "Anvndar och foruminstllningar";
$lang['Max_poll_options'] = "Maximalt antal val fr omrstningar";
$lang['Flood_Interval'] = "Tid mellan inlgg";
$lang['Flood_Interval_explain'] = "Antal sekunder en anvndare mste vnta mellan inlggen"; 
$lang['Board_email_form'] = "E-posta anvndare via forumet";
$lang['Board_email_form_explain'] = "Anvndare kan skicka e-post till varandra via forumet";
$lang['Topics_per_page'] = "mnen per sida";
$lang['Posts_per_page'] = "Inlgg per sida";
$lang['Hot_threshold'] = "Antal inlgg fr populritet";
$lang['Default_style'] = "Standardstil";
$lang['Override_style'] = "sidostt anvndarstil";
$lang['Override_style_explain'] = "Erstter anvndarens stil med standard stilen";
$lang['Default_language'] = "Standardsprk";
$lang['Date_format'] = "Datumformat";
$lang['System_timezone'] = "Systemets tidszon";
$lang['Enable_gzip'] = "Aktivera GZip Kompression";
$lang['Enable_prune'] = "Aktivera forum reducering";
$lang['Allow_HTML'] = "Tillt HTML";
$lang['Allow_BBCode'] = "Tillt BBCode";
$lang['Allowed_tags'] = "Tilltna HTML taggar";
$lang['Allowed_tags_explain'] = "Separera taggarna med komma";
$lang['Allow_smilies'] = "Tillt smilies";
$lang['Smilies_path'] = "Smilies skvg";
$lang['Smilies_path_explain'] = "Skvg under din phpBB root katalog, t.ex images/smilies";
$lang['Allow_sig'] = "Tillt signaturer";
$lang['Max_sig_length'] = "Maximal lngd p signaturen";
$lang['Max_sig_length_explain'] = "Maximalt antal tecken i anvndarens signatur";
$lang['Allow_name_change'] = "Tillt ndring av anvndarnamn";

$lang['Avatar_settings'] = "Avatarinstllningar";
$lang['Allow_local'] = "Aktivera galleriavatarer";
$lang['Allow_remote'] = "Aktivera fjrravatarer";
$lang['Allow_remote_explain'] = "Gr det mjligt att lnka till avatarer p andra websiter";
$lang['Allow_upload'] = "Aktivera Avataruppladdning";
$lang['Max_filesize'] = "Maximal Avatar filstorlek";
$lang['Max_filesize_explain'] = "Fr avatarer som laddas upp";
$lang['Max_avatar_size'] = "Maximal Avatar storlek";
$lang['Max_avatar_size_explain'] = "(Hjd x Bredd i pixelar)";
$lang['Avatar_storage_path'] = "Avatar skvg";
$lang['Avatar_storage_path_explain'] = "Skvg under din phpBB root katalog, t.ex. images/avatars";
$lang['Avatar_gallery_path'] = "Avatar galleriets skvg";
$lang['Avatar_gallery_path_explain'] = "Skvg under din phpBB root katalog fr fr-laddade bilder, t.ex. images/avatars/gallery";

$lang['COPPA_settings'] = "COPPA instllningar";
$lang['COPPA_fax'] = "COPPA fax nummer";
$lang['COPPA_mail'] = "COPPA adress";
$lang['COPPA_mail_explain'] = "Detta r adressen dit frldrar ska skicka registreringsforumlren fr COPPA";

$lang['Email_settings'] = "E-post instllningar";
$lang['Admin_email'] = "Admin e-post adress";
$lang['Email_sig'] = "E-post signatur";
$lang['Email_sig_explain'] = "Denna text kommer att bifogas i all e-post som forumet skickar.";
$lang['Use_SMTP'] = "Anvnd SMTP server fr epost";
$lang['Use_SMTP_explain'] = "Sg ja om du vill eller mste skicka e-post via en angiven server istllet fr via den lokala e-post funktionen";
$lang['SMTP_server'] = "SMTP server Adress";
$lang['SMTP_username'] = "SMTP Anvndarnamn";
$lang['SMTP_username_explain'] = "Skriv endast in ett anvndarnamn om din smtp server behver det";
$lang['SMTP_password'] = "SMTP Lsenord";
$lang['SMTP_password_explain'] = "Skriv endast in ett lsenord om din smtp server behver det";

$lang['Disable_privmsg'] = "Personliga Meddelandehantering";
$lang['Inbox_limits'] = "Max inlgg i Inldan";
$lang['Sentbox_limits'] = "Max inlgg i Skickade brev";
$lang['Savebox_limits'] = "Max inlgg i Sparade brev";

$lang['Cookie_settings'] = "Cookie instllningar"; 
$lang['Cookie_settings_explain'] = "Detta styr hur cookien som skickas till weblsaren r definerad. I de flesta fall s r standard instllningarna tillrckliga. Om du behver ndra dessa s gr det med varsamhet, felaktiga instllningar kan hindra anvndare frn att logga in";
$lang['Cookie_domain'] = "Cookie domn";
$lang['Cookie_name'] = "Cookie namn";
$lang['Cookie_path'] = "Cookie skvg";
$lang['Cookie_secure'] = "Cookie skerhet [ https ]";
$lang['Cookie_secure_explain'] = "Om servern krs via SSL aktivera det hr, annars lt det vara inaktiverat";
$lang['Session_length'] = "Sessionslngd [ sekunder ]";

// Visual Confirmation
$lang['Visual_confirm'] = 'Aktivera Visuell Bekrftning';
$lang['Visual_confirm_explain'] = 'Tvingar anvndare att ange en kod som visas genom bilder vid registrering.';

//
// Forum Management
//
$lang['Forum_admin'] = "Forum Administration";
$lang['Forum_admin_explain'] = "Frn denna panel kan du lgga till, radera, ndra, sortera och synkronisera katagorier och forum";
$lang['Edit_forum'] = "ndra forum";
$lang['Create_forum'] = "Skapa nytt forum";
$lang['Create_category'] = "Skapa ny kategori";
$lang['Remove'] = "Radera";
$lang['Action'] = "Handling";
$lang['Update_order'] = "Uppdatera sorteringsordning";
$lang['Config_updated'] = "Forumkonfigurationen r uppdaterad";
$lang['Edit'] = "ndra";
$lang['Delete'] = "Radera";
$lang['Move_up'] = "Flytta upp";
$lang['Move_down'] = "Flytta ner";
$lang['Resync'] = "Synkronisera";
$lang['No_mode'] = "Inget mode angavs";
$lang['Forum_edit_delete_explain'] = "Forumlret under lter dig skrddarsy alla allmnna foruminstllningar. Anvnd relaterad lnkar p vnster sida fr anvndar och forum konfiguraration";

$lang['Move_contents'] = "Flytta allt innehll";
$lang['Forum_delete'] = "Radera forum";
$lang['Forum_delete_explain'] = "Forumlret under lter dig radera ett forum (eller kategori) och tala om var du vill flytta alla mnen (eller forum) som det innehll.";

$lang['Status_locked'] = 'Lst';
$lang['Status_unlocked'] = 'ppen';
$lang['Forum_settings'] = "Generella foruminstllningar";
$lang['Forum_name'] = "Forumnamm";
$lang['Forum_desc'] = "Beskrivning";
$lang['Forum_status'] = "Forum status";
$lang['Forum_pruning'] = "Autoreducering";

$lang['prune_freq'] = 'Sk efter gamla mnen varje';
$lang['prune_days'] = "Ta bort mnen som inte har svarats p efter";
$lang['Set_prune_data'] = "Du har aktiverat autoreducering fr detta forum men har inte satt en frekvens eller antal dagar fr reducering. G tillbaka och stt detta";

$lang['Move_and_Delete'] = "Flytta och radera";

$lang['Delete_all_posts'] = "Radera alla inlgg";
$lang['Nowhere_to_move'] = "Ingenstans att flytta till";

$lang['Edit_Category'] = "ndra kategori";
$lang['Edit_Category_explain'] = "Anvnda detta forumlr fr att modifiera kategorinamnet.";

$lang['Forums_updated'] = "Forum och kategori-information r uppdaterad";

$lang['Must_delete_forums'] = "Du mste radera alla forum innan du kan radera denna kategori";

$lang['Click_return_forumadmin'] = "Klicka %shr%s fr att terg till Forum Administrationen";


//
// Smiley Management
//
$lang['smiley_title'] = "Smiles redigering";
$lang['smile_desc'] = "P denna sida kan du lgga till, radera och redigera emoticons eller smileys som dina anvndare kan anvnda i inlgg och personliga meddelanden.";

$lang['smiley_config'] = "Smiley konfiguration";
$lang['smiley_code'] = "Smiley kod";
$lang['smiley_url'] = "Smiley bildfil";
$lang['smiley_emot'] = "Smiley Emotion";
$lang['smile_add'] = "Lgg till en ny Smiley";
$lang['Smile'] = "Smile";
$lang['Emotion'] = "Emotion";

$lang['Select_pak'] = "Vlj paket (.pak) fil";
$lang['replace_existing'] = "Erstt befintlig Smiley";
$lang['keep_existing'] = "Behll befintlig Smiley";
$lang['smiley_import_inst'] = "Du br packa upp (unzip) smiley paketet och ladda upp alla filer till avsedd smiley katalog fr din installation. Sen stter du rtt information i detta formulr och importerar smiley paketet.";
$lang['smiley_import'] = "Smiley paket import";
$lang['choose_smile_pak'] = "Vlj en Smile Pack .pak fil";
$lang['import'] = "Importera Smileys";
$lang['smile_conflicts'] = "Vad ska gras om det finns konflikter";
$lang['del_existing_smileys'] = "Radera befintlig smileys fre import";
$lang['import_smile_pack'] = "Importera Smiley paket";
$lang['export_smile_pack'] = "Skapa Smiley paket";
$lang['export_smiles'] = "Fr att skapa ett smiley paket frn dina installerade smileys, klicka %shr%s fr att ladda ner smiles.pak filen. Ge filen ett passande namn och se till att behlla .pak tillgget.  Skapa sen en zip fil som innehller alla dina smileys bilder plus din .pak konfigurations fil.";

$lang['smiley_add_success'] = "Smileyn adderades.";
$lang['smiley_edit_success'] = "Smileyn uppdaterades";
$lang['smiley_import_success'] = "Smiley paketet r importerat!";
$lang['smiley_del_success'] = "Smileyn togs bort";
$lang['Click_return_smileadmin'] = "Klicka %shr%s fr att terg Smiley Administrationen";


//
// User Management
//
$lang['User_admin'] = "Anvndaradministration";
$lang['User_admin_explain'] = "Hr kan du ndra dina anvndares information och vissa specifika tillval. Fr att ndra anvndarens rttigheter s anvnd i anvndare och grupp rttigheter.";

$lang['Look_up_user'] = "Sl upp anvndare";

$lang['Admin_user_fail'] = "Kan inte uppdatera anvndarens profil.";
$lang['Admin_user_updated'] = "Anvndarens profil uppdaterades.";
$lang['Click_return_useradmin'] = "Klicka %shr%s fr att terg till anvndaradministrationen";

$lang['User_delete'] = "Radera denna anvndare";
$lang['User_delete_explain'] = "Klicka hr fr att radera denna anvndare, detta gr inte att ngra.";
$lang['User_deleted'] = "Anvndaren togs bort.";

$lang['User_status'] = "Anvndaren r aktiv";
$lang['User_allowpm'] = "Kan skicka personliga meddelanden";
$lang['User_allowavatar'] = "Kan visa avatar";

$lang['Admin_avatar_explain'] = "Hr kan du visa och radera anvndarens aktuella avatar.";

$lang['User_special'] = "Speciella admin flt";
$lang['User_special_explain'] = "Dessa flt kan inte ndras av anvndarna.  Hr kan du stta status och andra tillgg (val?) som inte finns tillgngliga fr anvndaren.";


//
// Group Management
//
$lang['No_group_action'] = 'Inget alternativ angavs'; 
$lang['Group_administration'] = "Grupp administration";
$lang['Group_admin_explain'] = "Via denna panel kan du administrera alla dina anvndaregrupper, du kan; radera, skapa nya och redigera existerande grupper. Du kan vlja moderatorer, ndra ppen/stngd status och stta gruppnamn och beskrivning";
$lang['Error_updating_groups'] = "Det uppstod ett fel nr grupperna skulle uppdateras";
$lang['Updated_group'] = "Gruppen r uppdaterad";
$lang['Added_new_group'] = "Den nya gruppen r skapad";
$lang['Deleted_group'] = "Gruppen r raderad";
$lang['New_group'] = "Skapa ny grupp";
$lang['Edit_group'] = "Redigera grupp";
$lang['group_name'] = "Gruppnamn";
$lang['group_description'] = "Gruppbeskrivning";
$lang['group_moderator'] = "Gruppmoderator";
$lang['group_status'] = "Gruppstatus";
$lang['group_open'] = "ppen grupp";
$lang['group_closed'] = "Stngd grupp";
$lang['group_hidden'] = "Dold grupp";
$lang['group_delete'] = "Radera grupp";
$lang['group_delete_check'] = "Radera denna grupp";
$lang['submit_group_changes'] = "Skicka ndringar";
$lang['reset_group_changes'] = "terstll ndringar";
$lang['No_group_name'] = "Du mste ange ett namn p gruppen";
$lang['No_group_moderator'] = "Du ste ange en moderator fr gruppen";
$lang['No_group_mode'] = "Du mste ange ett lge fr gruppen, ppen eller stngd";
$lang['delete_group_moderator'] = "Radera den gamla grupp moderatorn?";
$lang['delete_moderator_explain'] = "Om du ndrar grupp moderator, klicka i rutan fr att radera den gamla moderatorn frn gruppen.  Annars klicka inte i rutan s kommer den gamla moderatorn att bli en normal medlem i gruppen";
$lang['Click_return_groupsadmin'] = "Klicka %shr%s fr att terg till grupp administration.";
$lang['Select_group'] = "Vlj en grupp";
$lang['Look_up_group'] = "Sl upp en grupp";


//
// Prune Administration
//
$lang['Forum_Prune'] = "Forumreducering";
$lang['Forum_Prune_explain'] = "Detta kommer att radera alla mnen dr inga nya inlgg har skrivits inom det antal dagar du angett. Om du inte anger ett nummer s kommer alla mnen att raderas. Det kommer inte att radera mnen inom vilka omrstningar fortfarande r aktiva och det kommer inte heller att ta bort tillknnagivelser. Du behver radera dessa mnen manuellt";
$lang['Do_Prune'] = "Reducera";
$lang['All_Forums'] = "Alla forum";
$lang['Prune_topics_not_posted'] = "Radera mnen med inga svar i efter detta antal dagar";
$lang['Topics_pruned'] = "mnen reducerade";
$lang['Posts_pruned'] = "Inlgg reducerade";
$lang['Prune_success'] = "Reduceringen gick bra";


//
// Word censor
//
$lang['Words_title'] = "Censurering av ord";
$lang['Words_explain'] = "Frn denna kontrollpanel kan du lgga till, redigera och radera ord som automatiskt kommer at bli censurerade i dina forum. Dessutom kommer man inte att tilltas att registera anvndarnamn som innehller dessa ord. Wildcards (*) accepteras i ord fltet, eg. *test* matchar omtestning, test* matchar testning, *test matchar sluttest.";
$lang['Word'] = "Ord";
$lang['Edit_word_censor'] = "Redigera ordcensur";
$lang['Replacement'] = "Ersttning";
$lang['Add_new_word'] = "Lgg till nytt ord";
$lang['Update_word'] = "Uppdatera ordcensur";

$lang['Must_enter_word'] = "Du mste skriva ett ord och dess ersttning";
$lang['No_word_selected'] = "Inget ord r valt fr redigering";

$lang['Word_updated'] = "Censuren r uppdaterad";
$lang['Word_added'] = "Ordet har lagts till censuren";
$lang['Word_removed'] = "Ordet har tagits bort frn censuren";

$lang['Click_return_wordadmin'] = "Klicka %shr% fr att terg till censurering av ord";


//
// Mass Email
//
$lang['Mass_email_explain'] = "Hr kan du skicka ett e-post meddelande till antingen alla dina anvndare eller till anvndare i en specifik grupp.  Fr att kunna gra detta, kommer ett email att skickas till den administrativa epost adressen som du angett, med en bcc till alla mottagare. Ha lite tlamod om du mailar en stor grupp av mnniskor efter att ha skickat meddelandet och avbryt inte sidan halvvgs igenom. Det r normalt fr mass epost (spam) att ta en lngre tid, du kommer att meddelas nr skriptet r klart.";
$lang['Compose'] = "Komponerna"; 

$lang['Recipients'] = "Mottagare"; 
$lang['All_users'] = "Alla anvndare";

$lang['Email_successfull'] = "Ditt meddelande har skickats";
$lang['Click_return_massemail'] = "Klicka %shr%s fr att terg till mass e-post formulret";


//
// Ranks admin
//
$lang['Ranks_title'] = "Titel Administration";
$lang['Ranks_explain'] = "Via detta forumlr kan du skapa nya, redigera, visa och ta bort titlar. Du kan ocks skapa speciella titlar som kan tilldelas till en anvndare via anvndaradministration.";

$lang['Add_new_rank'] = "Lgg till en ny titel";

$lang['Rank_title'] = "Namn p titel";
$lang['Rank_special'] = "stt som speciell titel";
$lang['Rank_minimum'] = "Minimum antal inlgg";
$lang['Rank_maximum'] = "Maximum antal inlgg";
$lang['Rank_image'] = "Titel bild (relativt till phpBB2 root katalogen)";
$lang['Rank_image_explain'] = "Anvnda denna fr att tala om vilken bild som ska associeras med titeln";

$lang['Must_select_rank'] = "Du mste vlja en titel";
$lang['No_assigned_rank'] = "Ingen speciell titel tilldelad";

$lang['Rank_updated'] = "Titeln r uppdaterad";
$lang['Rank_added'] = "Titeln las till";
$lang['Rank_removed'] = "Titeln raderades";
$lang['No_update_ranks'] = 'Titeln raderades. Hursomhelst, anvndar konton som anvnder denna titel blev inte uppdaterade.  Du mste manuellt terstlla titeln p dessa konton.';

$lang['Click_return_rankadmin'] = "Klicka %shr%s fr att terg till Titel administration";


//
// Disallow Username Admin
//
$lang['Disallow_control'] = "Frbjuda anvndarnamn";
$lang['Disallow_explain'] = "Hr kan du styra vilka anvndarnamn som inte fr anvndas.  Frbjudna anvndarnamn fr innehlla wildcard (*).  Notera att du inte kan frbjuda redan registrerade anvndarnamn, du mste frst radera anvndaren fr att sedan frbjuda den";

$lang['Delete_disallow'] = "Radera";
$lang['Delete_disallow_title'] = "Radera ett frbjudet namn";
$lang['Delete_disallow_explain'] = "Du kan radera ett frbjudet anvndarnamn genom att vlja namnet frn listan och klicka p skicka";

$lang['Add_disallow'] = "Lgg till";
$lang['Add_disallow_title'] = "Lgg till ett frbjudet namn";
$lang['Add_disallow_explain'] = "Du kan frbjuda ett anvndarnamn med hjlp av jokertecknet * fr att matcha vilket tecken som helst";

$lang['No_disallowed'] = "Inga frbjudna anvndarnamn";

$lang['Disallowed_deleted'] = "Anvndarnamnet r giltigt igen";
$lang['Disallow_successful'] = "Anvndarnamnet har frbjudits";
$lang['Disallowed_already'] = "Namnet som du angav kan inte frbjudas. Antingen finns det redan i listan, eller i ordcensur listan, eller s finns anvndaren redan.";

$lang['Click_return_disallowadmin'] = "Klicka %shr%s fr att terg till Frbjuda anvndarnamn";


//
// Styles Admin
//
$lang['Styles_admin'] = "Stil Administration";
$lang['Styles_explain'] = "Genom denna kontrollpanel kan du lgga till, radera och hantera stilar (mallar och teman) som r tillgngliga fr dina anvndare";
$lang['Styles_addnew_explain'] = "Fljande lista innehller alla teman som r tillgngliga fr de mallar som du har. Artiklarna p denna lista har nnu inte blivit installerade i phpBB databasen. Fr att installera ett tema klicka p install lnken brevid en post.";

$lang['Select_template'] = "Vlj en mall";

$lang['Style'] = "Stil";
$lang['Template'] = "Mall";
$lang['Install'] = "Installera";
$lang['Download'] = "Ladda ner";

$lang['Edit_theme'] = "Redigera tema";
$lang['Edit_theme_explain'] = "I forumlret hr under kan du redigera instllningarna fr valt tema";

$lang['Create_theme'] = "Skapa tema";
$lang['Create_theme_explain'] = "Anvnd forumlret hr fr att skapa ett nytt tema fr vald mall. Nr du anger frger (vilka br anges i hexadecimal form) fr du inte inkludera #, i.e.. CCCCCC r giltigt, #CCCCCC r inte det.";

$lang['Export_themes'] = "Exportera teman";
$lang['Export_explain'] = "I denna kontrollpanel har du mjlighet att exportera tema data fr en mall. Vlj en mall frn listan och skriptet kommer att frska skapa en tema konfigurationsfil samt spara den till mall katalogen. Om skriptet inte kan spara filen sjlv kommer du att ges mjlighet att ladda hem den. Fr att skriptet ska kunna spara filen mste du ge skriv rttigheter till webserver i malla katalogen. Fr mer information om detta se phpBB 2 anvndarguide.";

$lang['Theme_installed'] = "Det valda temat har installerats.";
$lang['Style_removed'] = "Den valda stilen har tagits bort frn databasen. Fr att fullstndigt ta bort denna stil frn ditt system mste du radera de stilen frn din mall katalog.";
$lang['Theme_info_saved'] = "Tema information fr vald mall har sparats. Du br nu terstlla rttigheterna p theme_info.cfg (och p mall katalogen) till ls rttigheter.";
$lang['Theme_updated'] = "Det valda temat har uppdaterats. Du br nu exportera de nya tema instllningarna";
$lang['Theme_created'] = "Temat har skapas. Du br nu exportera temat till tema konfigurationsfilen fr skerhets skull och fr anvndning p andra forum";

$lang['Confirm_delete_style'] = "r du sker p att du vill radera denna stil";

$lang['Download_theme_cfg'] = "Exporeraren kunde inte spara tema informationsfilen. Klicka p kanppen nedan fr att ladda ner denna fil med din weblsare. Nr du har laddat hem den kan du verfra den till katalogen som innehller mall filerna. Du kan drefter paketera filerna fr distribution eller fr anvndning ngon annanstans om du s nskar";
$lang['No_themes'] = "Mallen du har valt har inga teman knuta till den. Skapa ett nytt tema genom att klicka p Skapa Ny lnken p vnster sida om panelen.";
$lang['No_template_dir'] = "Kan inte ppna mall katalogen. Den kan vara olsbar av webservern (kontrollera rttigheterna) eller saknas.";
$lang['Cannot_remove_style'] = "Du kan inte ta bort den valda stilen d den just nu r de forumets standard stil. ndra standard stil och frsk igen.";
$lang['Style_exists'] = "Stilen finns redan, g tillbaka ovh vlj ett annat namn.";

$lang['Click_return_styleadmin'] = "Klicka %sHr%s fr att terg till Stiladministrationen";

$lang['Theme_settings'] = "Temainstllningar";
$lang['Theme_element'] = "Tema Element";
$lang['Simple_name'] = "Enkelt namn";
$lang['Value'] = "Vrde";
$lang['Save_Settings'] = "Spara instllningar";

$lang['Stylesheet'] = "CSS Stylesheet";
$lang['Background_image'] = "Bakgrundsbild";
$lang['Background_color'] = "Bakgrundsfrg";
$lang['Theme_name'] = "Tema namn";
$lang['Link_color'] = "Lnkfrg";
$lang['Text_color'] = "Textfrg";
$lang['VLink_color'] = "Beskt lnkfrg";
$lang['ALink_color'] = "Aktiv lnkfrg";
$lang['HLink_color'] = "Hover lnkfrg";
$lang['Tr_color1'] = "Table Row Colour 1";
$lang['Tr_color2'] = "Table Row Colour 2";
$lang['Tr_color3'] = "Table Row Colour 3";
$lang['Tr_class1'] = "Table Row Class 1";
$lang['Tr_class2'] = "Table Row Class 2";
$lang['Tr_class3'] = "Table Row Class 3";
$lang['Th_color1'] = "Table Header Colour 1";
$lang['Th_color2'] = "Table Header Colour 2";
$lang['Th_color3'] = "Table Header Colour 3";
$lang['Th_class1'] = "Table Header Class 1";
$lang['Th_class2'] = "Table Header Class 2";
$lang['Th_class3'] = "Table Header Class 3";
$lang['Td_color1'] = "Table Cell Colour 1";
$lang['Td_color2'] = "Table Cell Colour 2";
$lang['Td_color3'] = "Table Cell Colour 3";
$lang['Td_class1'] = "Table Cell Class 1";
$lang['Td_class2'] = "Table Cell Class 2";
$lang['Td_class3'] = "Table Cell Class 3";
$lang['fontface1'] = "Textstil 1";
$lang['fontface2'] = "Textstil 2";
$lang['fontface3'] = "Textstil 3";
$lang['fontsize1'] = "Textstil 1";
$lang['fontsize2'] = "Textstil 2";
$lang['fontsize3'] = "Textstil 3";
$lang['fontcolor1'] = "Textfrg 1";
$lang['fontcolor2'] = "Textfrg 2";
$lang['fontcolor3'] = "Textfrg 3";
$lang['span_class1'] = "Span Class 1";
$lang['span_class2'] = "Span Class 2";
$lang['span_class3'] = "Span Class 3";
$lang['img_poll_size'] = "Omrstning bild storlek [px]";
$lang['img_pm_size'] = "Personligt meddelande status storlek [px]";


//
// Install Process
//
$lang['Welcome_install'] = "Vlkommen till phpBB 2 Installationen";
$lang['Initial_config'] = "Grundlggande  konfiguration";
$lang['DB_config'] = "Databas konfiguration";
$lang['Admin_config'] = "Admin konfiguration";
$lang['continue_upgrade'] = "Nr du har laddat ner din config fil till din lokala maskin kan du vlja \"Fortstta uppgraderingen\" knappen nedan fr att fortstta uppgraderingsprocessen. Vnta med att ladda upp config filen tills uppgraderingsprocessen r frdig.";
$lang['upgrade_submit'] = "Fortstta uppgraderingen";

$lang['Installer_Error'] = "Ett fel har uppsttt under installationen";
$lang['Previous_Install'] = "En fregende installation har upptckts";
$lang['Install_db_error'] = "Ett fel uppstod vid uppdateringen av databasen";

$lang['Re_install'] = "Din fregende installation r fortfarande aktiv. <br /><br />Om du vill ominstallera phpBB 2 br du klicka p Ja-knappen nedan. Var medveten om att detta frstr all befintlig data, ingen skerhetskopiering kommer att ske! Administratrs anvndarnamnet och lsenord som du har anvnt fr att logga in till forumet kommer att terskapas efter ominstallation, inga andra instllningar kommer att behllas. <br /><br />Tnk igenom det noga innan du trycker p Ja!";

$lang['Inst_Step_0'] = "Tack fr att du valt phpBB 2. Fr att fullborda installation fyll i information som efterfrgas nedan. Notera att databasen som du vill installera till mste finnas. Om du installerar till en databas som anvnder ODBC, e.g. MS Access s br du frst skapa en DSN fr den innan du gr vidare.";

$lang['Start_Install'] = "Starta installationen";
$lang['Finish_Install'] = "Avsluta installationen";

$lang['Default_lang'] = "Standardsprk i forumet";
$lang['DB_Host'] = "Databasserver vrdnamn / DSN";
$lang['DB_Name'] = "Ditt databasnamn";
$lang['DB_Username'] = "Databas anvndarnamn";
$lang['DB_Password'] = "Databas lsenord";
$lang['Database'] = "Din databas";
$lang['Install_lang'] = "Vlj sprk fr installation";
$lang['dbms'] = "Databastyp";
$lang['Table_Prefix'] = "Prefix fr tabeller i databasen";
$lang['Admin_Username'] = "Administratr anvndarnamn";
$lang['Admin_Password'] = "Administratr lsenord";
$lang['Admin_Password_confirm'] = "Administratr lsenord [ bekrfta ]";

$lang['Inst_Step_2'] = "Din administratrsanvndare har skapats. Vid detta tillflle r din grundinstallation frdig. Du kommer nu att skickas till en sida dr du har mjlighet att administrera din nya installation. Var god kontrollera dina Allmna instllningar och gr ndvndiga ndringar. Tack fr att du valt phpBB 2.";

$lang['Unwriteable_config'] = "Din config-fil r icke skrivbar fr tillfllet. En kopia av config filen kommer att skickas till dig nr du klickar p kanppen nedan. Du br ladda upp denna fil till samma katalog som phpBB 2. Nr detta r gjort br du logga in med ditt administratr anvndarnamn och lsenord (som du angav i ett tidigare formulr) och beska administratrskontrollpanelen (en lnk kommer att finns lngst ner p varje sida nr du vl har logga int) fr att kontrollera den allmnna konfigurationen. Tack fr att du valt phpBB 2.";
$lang['Download_config'] = "Ladda ner konfiguration";

$lang['ftp_choose'] = "Vlj nedladdningsmetod";
$lang['ftp_option'] = "<br />Eftersom FTP tillgg r aktiverat i denna version av PHP ges du ocks mjlighet att frska ftp:a config filen till servern helt automatiskt.";
$lang['ftp_instructs'] = "Du har valt att ftp:a filen till kontot som har phpBB 2 helt automatiskt. Ange informationen som saknas nedan. Notera att FTP skvgen ska vara exakt samma skvg till din phpBB 2 installation som du skulle anvnda om du anvnder en vanlig ftp klient.";
$lang['ftp_info'] = "Ange din FTP information";
$lang['Attempt_ftp'] = "Frsker skriva config-filen till rtt stlle via ftp";
$lang['Send_file'] = "Skicka filen till mig s fixar jag det manuellt via ftp";
$lang['ftp_path'] = "FTP skvg till phpBB 2";
$lang['ftp_username'] = "Ditt FTP anvndarnamn";
$lang['ftp_password'] = "Ditt FTP lsenord";
$lang['Transfer_config'] = "Starta verfring";
$lang['NoFTP_config'] = "Frsket att ftp:a config-filen misslyckades. Ladda hem filen och ftp:a upp filen manuellt.";

$lang['Install'] = "Installera";
$lang['Upgrade'] = "Uppgradera";


$lang['Install_Method'] = "Vlj installationsmetod";

$lang['Install_No_Ext'] = "PHP konfigurationen p din server stdjer inte den databas typ du har valt";

$lang['Install_No_PCRE'] = "phpBB2 krver den \"Perl-Compatible Regular Expressions Module for php\" vilket din php konfiguration inte stdjer";

//
// That's all Folks!
// -------------------------------------------------

?>